@@ -3,7 +3,7 @@
 // Purpose:     The video properties dialog
 // Author:      Alex Thuering
 // Created:     09.09.2010
-// RCS-ID:      $Id: VideoPropDlg.cpp,v 1.23 2015/09/17 13:35:55 ntalex Exp $
+// RCS-ID:      $Id: VideoPropDlg.cpp,v 1.27 2016/12/17 17:27:38 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -11,6 +11,7 @@
 #include "VideoPropDlg.h"
 #include "DVD.h"
 #include "Utils.h"
+#include "Config.h"
 #include <wx/artprov.h>
 #include <wx/regex.h>
 
@@ -66,7 +67,8 @@ BEGIN_EVENT_TABLE(VideoPropDlg,wxDialog)
 	EVT_COMMAND_SCROLL(ID_SLIDER, VideoPropDlg::OnSliderScroll)
 END_EVENT_TABLE()
 
-VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
+VideoPropDlg::VideoPropDlg(wxWindow* parent, DVD* dvd, Vob* vob, AspectRatio aspectRatio) {
+	m_dvd = dvd;
 	m_vob = vob;
 	m_stream = vob->GetVideoStream();
 	m_aspectRatio = aspectRatio;
@@ -105,15 +107,16 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
 	fileNameLabel = new wxStaticText(this, wxID_ANY, _("File Name:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
 	gridBagSizer->Add(fileNameLabel, wxGBPosition(0, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
 	m_fileNameText = new wxStaticText(this, ID_STATICTEXT2, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT2"));
-	gridBagSizer->Add(m_fileNameText, wxGBPosition(0, 1), wxDefaultSpan, wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	m_fileNameText->SetMinSize(wxSize(8,8));
+	gridBagSizer->Add(m_fileNameText, wxGBPosition(0, 1), wxDefaultSpan, wxEXPAND, 5);
 	durLabel = new wxStaticText(this, wxID_ANY, _("Duration:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
 	gridBagSizer->Add(durLabel, wxGBPosition(1, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
 	m_durText = new wxStaticText(this, ID_STATICTEXT4, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT4"));
-	gridBagSizer->Add(m_durText, wxGBPosition(1, 1), wxDefaultSpan, wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	gridBagSizer->Add(m_durText, wxGBPosition(1, 1), wxDefaultSpan, wxEXPAND, 5);
 	srcLabel = new wxStaticText(this, wxID_ANY, _("Source Format:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
 	gridBagSizer->Add(srcLabel, wxGBPosition(2, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
 	m_srcText = new wxStaticText(this, ID_STATICTEXT3, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT3"));
-	gridBagSizer->Add(m_srcText, wxGBPosition(2, 1), wxDefaultSpan, wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	gridBagSizer->Add(m_srcText, wxGBPosition(2, 1), wxDefaultSpan, wxEXPAND, 5);
 	dstLabel = new wxStaticText(this, wxID_ANY, _("Destination Format:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
 	gridBagSizer->Add(dstLabel, wxGBPosition(3, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
 	dstSizer = new wxBoxSizer(wxHORIZONTAL);
@@ -130,16 +133,16 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
 	m_ffChoice->Append(_("BFF"));
 	m_ffChoice->Append(_("TFF"));
 	dstSizer->Add(m_ffChoice, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-	gridBagSizer->Add(dstSizer, wxGBPosition(3, 1), wxDefaultSpan, wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	gridBagSizer->Add(dstSizer, wxGBPosition(3, 1), wxDefaultSpan, wxEXPAND, 5);
 	aspectSizer = new wxBoxSizer(wxHORIZONTAL);
 	m_keepAspectCtrl = new wxCheckBox(this, KEEP_ASPECT_CB_ID, _("Keep Aspect Ratio"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("KEEP_ASPECT_CB_ID"));
 	m_keepAspectCtrl->SetValue(false);
-	aspectSizer->Add(m_keepAspectCtrl, 0, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	aspectSizer->Add(m_keepAspectCtrl, 0, wxALIGN_CENTER_VERTICAL, 5);
 	m_keepAspectChoice = new wxChoice(this, KEEP_ASPECT_CHOICE_ID, wxDefaultPosition, wxDefaultSize, 0, 0, 0, wxDefaultValidator, _T("KEEP_ASPECT_CHOICE_ID"));
 	m_keepAspectChoice->SetSelection( m_keepAspectChoice->Append(_("border")) );
 	m_keepAspectChoice->Append(_("crop"));
 	aspectSizer->Add(m_keepAspectChoice, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-	gridBagSizer->Add(aspectSizer, wxGBPosition(4, 0), wxGBSpan(1, 2), wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	gridBagSizer->Add(aspectSizer, wxGBPosition(4, 0), wxGBSpan(1, 2), wxEXPAND, 5);
 	padCropSizer = new wxBoxSizer(wxHORIZONTAL);
 	m_padBox = new wxStaticBoxSizer(wxHORIZONTAL, this, _("Border"));
 	borderSizer = new wxGridBagSizer(2, 2);
@@ -173,7 +176,7 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
 	cropBagSizer->Add(m_cropLeft, wxGBPosition(1, 0), wxDefaultSpan, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
 	m_cropBox->Add(cropBagSizer, 1, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
 	padCropSizer->Add(m_cropBox, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-	gridBagSizer->Add(padCropSizer, wxGBPosition(5, 0), wxGBSpan(1, 2), wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
+	gridBagSizer->Add(padCropSizer, wxGBPosition(5, 0), wxGBSpan(1, 2), wxEXPAND, 5);
 	fadeLabel = new wxStaticText(this, wxID_ANY, _("Fade-In/Out:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
 	gridBagSizer->Add(fadeLabel, wxGBPosition(6, 0), wxDefaultSpan, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
 	filterLabel = new wxStaticText(this, wxID_ANY, _("Filters:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
@@ -189,30 +192,30 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
 	fadeSizer->Add(m_fadeOutCtrl, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	StaticText8 = new wxStaticText(this, wxID_ANY, _("sec"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
 	fadeSizer->Add(StaticText8, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
-	gridBagSizer->Add(fadeSizer, wxGBPosition(6, 1), wxDefaultSpan, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	gridBagSizer->Add(fadeSizer, wxGBPosition(6, 1), wxDefaultSpan, wxEXPAND, 5);
 	m_filtersCtrl = new wxTextCtrl(this, ID_TEXTCTRL1, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL1"));
-	gridBagSizer->Add(m_filtersCtrl, wxGBPosition(7, 1), wxDefaultSpan, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-	hSizer->Add(gridBagSizer, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	gridBagSizer->Add(m_filtersCtrl, wxGBPosition(7, 1), wxDefaultSpan, wxEXPAND, 5);
+	hSizer->Add(gridBagSizer, 0, wxALL|wxEXPAND, 5);
 	mediaSizer = new wxBoxSizer(wxVERTICAL);
 	m_mediaCtrl = new MediaCtrlFF(this, ID_CUSTOM1, wxT(""), wxDefaultPosition,wxDefaultSize, 0, wxDefaultValidator, _T("ID_CUSTOM1"));
 	m_mediaCtrl->SetMinSize(wxSize(300, 200));
 	m_mediaCtrl->SetWindowStyle(wxBORDER_NONE);
-	mediaSizer->Add(m_mediaCtrl, 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 4);
+	mediaSizer->Add(m_mediaCtrl, 1, wxALL|wxEXPAND, 4);
 	m_slider = new wxSlider(this, ID_SLIDER, 0, 0, 100, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_SLIDER"));
-	mediaSizer->Add(m_slider, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
+	mediaSizer->Add(m_slider, 0, wxEXPAND, 2);
 	timeSizer = new wxBoxSizer(wxHORIZONTAL);
 	staticText1 = new wxStaticText(this, wxID_ANY, _("Time:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
 	timeSizer->Add(staticText1, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 4);
 	m_timeCtrl = new wxTextCtrl(this, ID_TIME_CTRL, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TIME_CTRL"));
-	timeSizer->Add(m_timeCtrl, 0, wxLEFT|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
+	timeSizer->Add(m_timeCtrl, 0, wxLEFT|wxEXPAND, 2);
 	m_timeSpinBt = new wxSpinButton(this, ID_TIME_SPINB, wxDefaultPosition, wxDefaultSize, wxSP_VERTICAL|wxSP_ARROW_KEYS, _T("ID_TIME_SPINB"));
 	m_timeSpinBt->SetRange(0, 100);
 	m_timeSpinBt->SetMinSize(wxSize(16,12));
-	timeSizer->Add(m_timeSpinBt, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	timeSizer->Add(m_timeSpinBt, 0, wxEXPAND, 5);
 	m_frameSpinBt = new wxSpinButton(this, ID_FRAME_SPINBT, wxDefaultPosition, wxDefaultSize, wxSP_VERTICAL|wxSP_ARROW_KEYS|wxSP_WRAP, _T("ID_FRAME_SPINBT"));
 	m_frameSpinBt->SetRange(-9999, 9999);
 	m_frameSpinBt->SetMinSize(wxSize(16,12));
-	timeSizer->Add(m_frameSpinBt, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	timeSizer->Add(m_frameSpinBt, 0, wxEXPAND, 5);
 	startLabel = new wxStaticText(this, wxID_ANY, _("Start:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
 	timeSizer->Add(startLabel, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 8);
 	m_startCtrl = new wxTextCtrl(this, ID_TEXTCTRL2, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL2"));
@@ -220,11 +223,11 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
 	m_startSpin = new wxSpinButton(this, ID_SPINBUTTON1, wxDefaultPosition, wxDefaultSize, wxSP_VERTICAL|wxSP_ARROW_KEYS|wxSP_WRAP, _T("ID_SPINBUTTON1"));
 	m_startSpin->SetRange(-9999, 9999);
 	m_startSpin->SetMinSize(wxSize(16,12));
-	timeSizer->Add(m_startSpin, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	timeSizer->Add(m_startSpin, 0, wxEXPAND, 5);
 	m_startFrameSpin = new wxSpinButton(this, ID_SPINBUTTON2, wxDefaultPosition, wxDefaultSize, wxSP_VERTICAL|wxSP_ARROW_KEYS|wxSP_WRAP, _T("ID_SPINBUTTON2"));
 	m_startFrameSpin->SetRange(-9999, 9999);
 	m_startFrameSpin->SetMinSize(wxSize(16,12));
-	timeSizer->Add(m_startFrameSpin, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	timeSizer->Add(m_startFrameSpin, 0, wxEXPAND, 5);
 	m_startBt = new wxBitmapButton(this, START_BT_ID, wxArtProvider::GetBitmap(wxART_MAKE_ART_ID_FROM_STR(_T("wxART_CUT")),wxART_MENU), wxDefaultPosition, wxDefaultSize, wxBU_AUTODRAW, wxDefaultValidator, _T("START_BT_ID"));
 	m_startBt->SetDefault();
 	m_startBt->SetToolTip(_("Cut beginning"));
@@ -236,23 +239,23 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
 	m_endSpin = new wxSpinButton(this, ID_SPINBUTTON3, wxDefaultPosition, wxDefaultSize, wxSP_VERTICAL|wxSP_ARROW_KEYS|wxSP_WRAP, _T("ID_SPINBUTTON3"));
 	m_endSpin->SetRange(-9999, 9999);
 	m_endSpin->SetMinSize(wxSize(16,12));
-	timeSizer->Add(m_endSpin, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
+	timeSizer->Add(m_endSpin, 0, wxEXPAND, 0);
 	m_endFrameSpin = new wxSpinButton(this, ID_SPINBUTTON4, wxDefaultPosition, wxDefaultSize, wxSP_VERTICAL|wxSP_ARROW_KEYS|wxSP_WRAP, _T("ID_SPINBUTTON4"));
 	m_endFrameSpin->SetRange(-9999, 9999);
 	m_endFrameSpin->SetMinSize(wxSize(16,12));
-	timeSizer->Add(m_endFrameSpin, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
+	timeSizer->Add(m_endFrameSpin, 0, wxEXPAND, 0);
 	m_endBt = new wxBitmapButton(this, ID_RESET_TIME_BT, wxArtProvider::GetBitmap(wxART_MAKE_ART_ID_FROM_STR(_T("wxART_CUT")),wxART_MENU), wxDefaultPosition, wxDefaultSize, wxBU_AUTODRAW, wxDefaultValidator, _T("ID_RESET_TIME_BT"));
 	m_endBt->SetDefault();
 	m_endBt->SetToolTip(_("Cut ending"));
-	timeSizer->Add(m_endBt, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
-	mediaSizer->Add(timeSizer, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-	hSizer->Add(mediaSizer, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-	mainSizer->Add(hSizer, 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	timeSizer->Add(m_endBt, 0, wxEXPAND, 2);
+	mediaSizer->Add(timeSizer, 0, wxALL|wxEXPAND, 5);
+	hSizer->Add(mediaSizer, 1, wxEXPAND, 5);
+	mainSizer->Add(hSizer, 1, wxALL|wxEXPAND, 5);
 	stdDialogButtonSizer = new wxStdDialogButtonSizer();
 	stdDialogButtonSizer->AddButton(new wxButton(this, wxID_OK, wxEmptyString));
 	stdDialogButtonSizer->AddButton(new wxButton(this, wxID_CANCEL, wxEmptyString));
 	stdDialogButtonSizer->Realize();
-	mainSizer->Add(stdDialogButtonSizer, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 4);
+	mainSizer->Add(stdDialogButtonSizer, 0, wxALL|wxEXPAND, 4);
 	SetSizer(mainSizer);
 	SetSizer(mainSizer);
 	Layout();
@@ -294,6 +297,7 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
 	m_endCtrl->SetMinSize(wxSize(x + 10, -1));
 
     m_fileNameText->SetLabel(m_vob->GetFilenameDisplay());
+    m_fileNameText->SetToolTip(m_vob->GetFilenameDisplay());
     // duration
 	wxString s = wxT("N/A");
 	if (m_vob->GetDuration()>0) {
@@ -308,8 +312,18 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
     m_srcText->SetLabel(m_stream->GetSourceFormat());
 
     // format
-    m_dstChoice->Append(DVD::GetVideoFormatLabels(true));
-    m_dstChoice->SetSelection(m_stream->GetVideoFormat() - 1);
+    bool copyEnabled = m_stream->IsCopyPossible();
+    m_dstChoice->Append(DVD::GetVideoFormatLabels(copyEnabled, false, false, m_dvd->IsHD()));
+	int vf = m_stream->GetVideoFormat();
+	if (m_dvd->IsHD()) {
+		if (vf >= vfPAL_HALF_HD) {
+			vf = vf - vfPAL_HALF_HD + (copyEnabled ? 1 : 0);
+		} else
+			vf =  vf >= vfPAL && vf < vfPAL_HALF_HD ? vf + (copyEnabled ? 5 : 4) : 0;
+	} else {
+		vf -= (copyEnabled ? 1 : 2);
+	}
+    m_dstChoice->SetSelection(vf);
     m_aspectChoice->Append(DVD::GetAspectRatioLabels());
     m_aspectChoice->SetSelection(m_aspectRatio - 1);
     m_interlacedChoice->SetSelection(m_vob->GetInterlaced() ? 1 : 0);
@@ -382,7 +396,25 @@ double TimeToDouble(wxString timeStr) {
 }
 
 VideoFormat VideoPropDlg::GetVideoFormat() {
-	return (VideoFormat) (m_dstChoice->GetSelection() + 1);
+	int vf = m_dstChoice->GetSelection();
+	if (m_dvd->IsHD()) {
+		if (m_stream->IsCopyPossible()) {
+			if (vf == 0) {
+				vf = vfCOPY;
+			} else if (vf <= 6) {
+				vf += vfPAL_HALF_HD - 1;
+			} else
+				vf -= 5;
+		} else {
+			if (vf <= 5) {
+				vf += vfPAL_HALF_HD;
+			} else
+				vf -= 4;
+		}
+	} else {
+		vf += (m_stream->IsCopyPossible() ? 1 : 2);
+	}
+	return (VideoFormat) vf;
 }
 
 AspectRatio VideoPropDlg::GetAspectRatio() {
@@ -421,10 +453,35 @@ int VideoPropDlg::ShowModal() {
 		m_vob->SetFadeIn(m_fadeInCtrl->GetValue());
 		m_vob->SetFadeOut(m_fadeOutCtrl->GetValue());
 		m_vob->SetVideoFilters(m_filtersCtrl->GetValue());
+		
+		double durationOld = m_vob->GetResultDuration();
 		double time = TimeToDouble(m_startCtrl->GetValue());
 		m_vob->SetStartTime(time >= 0 ? time : 0);
 		time = TimeToDouble(m_endCtrl->GetValue());
 		m_vob->SetRecordingTime(time > m_vob->GetStartTime() ? time - m_vob->GetStartTime() : -1);
+		if (durationOld != m_vob->GetResultDuration()) {
+			// remove chapter at the end
+			long duration = (long) durationOld;
+			if (s_config.GetAddChapterAtTitleEnd() && m_vob->GetCells().size() > 0 &&
+					m_vob->GetCells()[m_vob->GetCells().size() - 1]->GetStart() == (duration - 1)*1000) {
+				m_vob->GetCells().erase(m_vob->GetCells().end() - 1);
+			}
+			// remove chapters > duration
+			duration = (long) m_vob->GetResultDuration()*1000;
+			unsigned int i = 0;
+			while (i < m_vob->GetCells().size()) {
+				if (m_vob->GetCells()[i]->GetStart() > duration) {
+					m_vob->GetCells().erase(m_vob->GetCells().begin() + i);
+				} else
+					i++;
+			}
+			// add chapter at the end
+			duration = (long) m_vob->GetResultDuration();
+			if (s_config.GetAddChapterAtTitleEnd() && (m_vob->GetCells().size() == 0 ||
+					m_vob->GetCells()[m_vob->GetCells().size() - 1]->GetStart() < (duration - 1)*1000)) {
+				m_vob->GetCells().push_back(new Cell((duration - 1)* 1000));
+			}
+		}
 	}
 	return res;
 }
@@ -550,7 +607,7 @@ void VideoPropDlg::OnChangeFormat(wxCommandEvent& event) {
 	m_lastFormat = GetVideoFormat();
 
 	// enable/disable controls
-	bool enable = m_dstChoice->GetSelection() > 0;
+	bool enable = GetVideoFormat() != vfCOPY;
 	bool enablePad = enable && !m_keepAspectCtrl->GetValue();
 	m_interlacedChoice->Enable(enable);
 	m_keepAspectCtrl->Enable(enable);
